@@ -33,6 +33,8 @@ def test_train_loop():
     seq_encoder = SequenceEncoder(
         category_features={'mcc_code': 21, 'trans_type': 11},
         numeric_features=["amount"],
+        encoder_type='rnn',
+        rnn_hidden_size=16,
     )
     head = Head(
         input_size=seq_encoder.embedding_size,
@@ -45,6 +47,6 @@ def test_train_loop():
 
     params = tst_params()
 
-    dl = RandomEventData(params['data_module'])
+    dl = RandomEventData(params.data_module)
     trainer = pl.Trainer(max_epochs=1, logger=None, checkpoint_callback=False)
     trainer.fit(model, dl)
