@@ -1,8 +1,10 @@
 import torch
 import numpy as np
+from omegaconf import OmegaConf
 
 from ptls.trx_encoder import PaddedBatch
 from ptls.seq_encoder.rnn_encoder import RnnSeqEncoder
+from ptls.trx_encoder import TrxEncoder
 
 
 def get_data():
@@ -17,9 +19,9 @@ def get_data():
                       )
 
 def test_shape():
-    
+
     params = {
-        'trx_encoder' : {
+        'trx_encoder': {
             'norm_embeddings': False,
             'embeddings_noise': 0.003,
             'embeddings': {
@@ -43,8 +45,12 @@ def test_shape():
             'trainable_starter': 'static',
         }
     }
+    params = OmegaConf.create(params)
 
-    model = RnnSeqEncoder(params, True)
+    model = RnnSeqEncoder(
+        trx_encoder=TrxEncoder(**params['trx_encoder']),
+        **params['rnn'],
+    )
 
     x = get_data()
 
